@@ -1,7 +1,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: June 6, 2013
+# Last Change: June 7, 2013
 # URL: https://github.com/paylogic/pip-accel
 #
 # TODO Permanently store logs in the pip-accel directory (think about log rotation).
@@ -71,9 +71,9 @@ HOME = pwd.getpwuid(os.getuid()).pw_dir
 
 def expanduser(pathname):
     """
-    Variant of os.path.expanduser() that doesn't use $HOME but instead uses the
-    home directory of the effective user id. This is basically a workaround for
-    ``sudo -s`` not resetting $HOME.
+    Variant of :py:func:`os.path.expanduser()` that doesn't use ``$HOME`` but
+    instead uses the home directory of the effective user id. This is basically
+    a workaround for ``sudo -s`` not resetting ``$HOME``.
     """
     return re.sub('^~(?=/)', HOME, pathname)
 
@@ -100,7 +100,7 @@ index_version_file = os.path.join(pip_accel_cache, 'version.txt')
 
 def main():
     """
-    Main logic of the pip-accel command.
+    Main logic of the ``pip-accel`` command.
     """
     arguments = sys.argv[1:]
     if not arguments:
@@ -142,20 +142,21 @@ def unpack_source_dists(arguments):
     """
     Check whether there are local source distributions available for all
     requirements, unpack the source distribution archives and find the names
-    and versions of the requirements. By using the "pip install --no-install"
+    and versions of the requirements. By using the ``pip install --no-install``
     command we avoid reimplementing the following pip features:
 
-     - Parsing of "requirements.txt" (including recursive parsing)
+     - Parsing of ``requirements.txt`` (including recursive parsing)
      - Resolution of possibly conflicting pinned requirements
      - Unpacking source distributions in multiple formats
      - Finding the name & version of a given source distribution
 
     Expects one argument: a list of strings with the command line arguments to
-    be passed to the `pip` command.
+    be passed to the ``pip`` command.
 
-    Returns the list of tuples also returned by and documented under the
-    parse_requirements() function, unless `pip` fails in which case None is
-    returned instead.
+    Returns a list of tuples with three strings each: The name of a requirement
+    (package), its version number and the directory where the unpacked source
+    distribution is located. If ``pip`` fails, an exception will be raised by
+    ``pip``.
     """
     unpack_timer = Timer()
     logger.info("Unpacking local source distributions ..")
@@ -225,8 +226,8 @@ def find_binary_dists():
     """
     Find all previously cached binary distributions.
 
-    Returns a dictionary with (package-name, package-version) tuples as keys
-    and pathnames of binary archives as values.
+    Returns a dictionary with (package-name, package-version, python-version)
+    tuples as keys and pathnames of binary archives as values.
     """
     logger.info("Scanning binary distribution index ..")
     distributions = {}
@@ -251,11 +252,11 @@ def build_binary_dists(requirements):
     Convert source distributions to binary distributions.
 
     Expects a list of tuples in the format of the return value of the
-    parse_requirements() function.
+    :py:func:`unpack_source_dists()` function.
 
-    Returns True if it succeeds in building a binary distribution, False
-    otherwise (probably because of missing binary dependencies like system
-    libraries).
+    Returns ``True`` if it succeeds in building a binary distribution,
+    ``False`` otherwise (probably because of missing binary dependencies like
+    system libraries).
     """
     existing_binary_dists = find_binary_dists()
     logger.info("Building binary distributions ..")
@@ -294,10 +295,10 @@ def build_binary_dists(requirements):
 
 def cache_binary_distribution(input_path, output_path):
     """
-    Transform a binary distribution archive created with `python setup.py
-    bdist_dumb --format=gztar` into a form that can be cached for future use.
+    Transform a binary distribution archive created with ``python setup.py
+    bdist_dumb --format=gztar`` into a form that can be cached for future use.
     This comes down to making the pathnames inside the archive relative to the
-    "prefix" that the binary distribution was built for.
+    `prefix` that the binary distribution was built for.
 
     Expects two arguments: The pathname of the original binary distribution
     archive and the pathname of the binary distribution in the cache
@@ -336,11 +337,11 @@ def install_requirements(requirements, install_prefix=ENVIRONMENT):
     """
     Manually install all requirements from binary distributions.
 
-    Expects a list of tuples in the format of the return value of the
-    parse_requirements() function.
+    Expects a list of tuples in the format of the return value of
+    :py:func:`unpack_source_dists()`.
 
-    Returns True if it succeeds in installing all requirements from binary
-    distribution archives, False otherwise.
+    Returns ``True`` if it succeeds in installing all requirements from binary
+    distribution archives, ``False`` otherwise.
     """
     install_timer = Timer()
     existing_binary_dists = find_binary_dists()
@@ -357,8 +358,9 @@ def install_requirements(requirements, install_prefix=ENVIRONMENT):
 
 def install_binary_dist(filename, install_prefix=ENVIRONMENT):
     """
-    Install a binary distribution created with `python setup.py bdist` into the
-    given prefix (a directory like /usr, /usr/local or a virtual environment).
+    Install a binary distribution created with ``python setup.py bdist`` into
+    the given prefix (a directory like ``/usr``, ``/usr/local`` or a virtual
+    environment).
 
     Expects two arguments: The pathname of the tar archive and the pathname of
     the installation prefix.
@@ -420,15 +422,16 @@ def fix_hashbang(python, contents):
 
 def run_pip(arguments, use_remote_index):
     """
-    Execute a modified `pip install` command. This function assumes that the
-    arguments concern a "pip install" command.
+    Execute a modified ``pip install`` command. This function assumes that the
+    arguments concern a ``pip install`` command (:py:func:`main()` makes sure
+    of this).
 
     Expects two arguments: A list of strings containing the arguments that will
-    be passed to `pip` followed by a boolean indicating whether `pip` may
+    be passed to ``pip`` followed by a boolean indicating whether ``pip`` may
     contact http://pypi.python.org.
 
-    Returns a pip RequirementSet object. If pip reports an error, the exception
-    will be re-raised by the run_pip() function.
+    Returns a pip ``RequirementSet`` object, unless an exception raised by
+    ``pip`` (in which case the exception will bubble up).
     """
     command_line = []
     for i, arg in enumerate(arguments):
@@ -458,12 +461,12 @@ def run_pip(arguments, use_remote_index):
 class CustomInstallCommand(InstallCommand):
 
     """
-    InstallCommand.run() returns a RequirementSet object which pip-accel is
-    interested in, however pip.basecommand.Command.main() swallows the
-    requirement set (based on my reading of the pip 1.3.x source code). This
-    is why we subclass InstallCommand to wrap the run() method :-). Yes, this
-    is a bit sneaky, but I don't fancy reimplementing
-    pip.basecommand.Command.main() inside pip-accel...
+    ``InstallCommand.run()`` returns a ``RequirementSet`` object which
+    `pip-accel` is interested in, however ``pip.basecommand.Command.main()``
+    swallows the requirement set (based on my reading of the pip 1.3.x source
+    code). This is why we subclass ``InstallCommand`` to wrap the run() method
+    :-). Yes, this is a bit sneaky, but I don't fancy reimplementing
+    ``pip.basecommand.Command.main()`` inside `pip-accel`...
     """
 
     def run(self, *args, **kw):
@@ -498,7 +501,7 @@ def get_python_version():
     """
     Return a string identifying the currently running Python version.
     """
-    return "py%i.%i" % (sys.version_info.major, sys.version_info.minor)
+    return "py%i.%i" % (sys.version_info[0], sys.version_info[1])
 
 def add_extension(download_path, archive_path):
     """
@@ -515,9 +518,9 @@ def add_extension(download_path, archive_path):
     source index directory.
 
     Previously this used the "file" executable, now it checks the magic file
-    headers itself. I could have used any of the numerous libmagic bindings on
-    PyPi, but that would add a binary dependency to pip-accel and I don't want
-    that :-).
+    headers itself. I could have used any of the numerous ``libmagic`` bindings
+    on PyPi, but that would add a binary dependency to `pip-accel` and I don't
+    want that :-).
     """
     handle = open(download_path)
     header = handle.read(2)
